#!/bin/sh

set -x
set -e
set -u
set +f

BUILD_ID="${BUILD_ID:-XXX}"
FS_LABEL="ROSA_2021.1_Plasma5_${BUILD_ID}"
ARCH="${ARCH:-x86_64}"
AARCH64_TEST="${AARCH64_TEST:-0}"
SLEEP="${SLEEP:-0}"

# x86_64 by default
conf="$(mktemp)"
cp plasma5.ks "$conf"
repobase="$(mktemp)"
cp repobase.ks "$repobase"
pkgs="$(mktemp)"
cp plasma5pack.ks "$pkgs"

if [ "$ARCH" = "aarch64" ] || [ "$AARCH64_TEST" = "1" ]; then
	if [ "$ARCH" = "aarch64" ]; then
		FS_LABEL="Plasma5_aarch64_${BUILD_ID}"
		sed -i "s/x86_64/aarch64/" "$repobase"
		sed -i "s/^syslinux$/-&/" "$pkgs"
	else
		FS_LABEL="Plasma5_x86aarch_${BUILD_ID}"
		ARCH="x86_64"
	fi
# Drop or rename break aarch64 packages
# ExclusiveArch: vbetool, x11-driver-input-vmmouse, memtest86+, iscan-nonfree, kernel-modules-virtualbox-guest-generic-5.4-latest, microcode_ctl, ml85p, lib64dri-drivers-intel
	sed -i "/^\(nomacs\|vbetool\|dkms-vboxadditions\|x11-driver-input-vmmouse\|memtest86+\|dkms-minimal\|iscan-nonfree\|kernel-modules-virtualbox-guest-generic-5.4-latest\|microcode_ctl\|ml85p\|openl2tp\|rsyslog\|sasl-plug-gssapi\|trojita\|vaapi-driver-intel\|virtualbox-guest-additions\|x11-data-xkbdata\|pango\|mktemp\|dbus\|kernel-source-virtualbox\|kernel-source-virtualbox-vboxadditions\|lib64dri-drivers-intel\|libnss-role\|kdenlive\|kde-dev-scripts\)$/d" "$pkgs"
	sed -i "s/^alsa-plugins$/lib64&/" "$pkgs"
	sed -i "s/^alsa-plugins-pulseaudio$/lib64&/" "$pkgs"
	sed -i "s/^indexhtml$/branding-configs-fresh/" "$pkgs"
	sed -i "s/^canberra-gtk$/&3/" "$pkgs"
	sed -i "s/^gnupg$/&1/" "$pkgs"
	sed -i "s/^libvdpau-va-gl$/lib64vdpau_va_gl1/" "$pkgs"
	sed -i "s/^nss_wins$/lib64nsswins2/" "$pkgs"
	sed -i "s/^procps$/&-ng/" "$pkgs"
	sed -i "s/^qt5-imageformats-plugins$/lib64qt5imageformats-plugins/" "$pkgs"
	sed -i "s/^shim$/&-unsigned/" "$pkgs"
	sed -i "s/^vim$/&-minimal/" "$pkgs"
	echo "open-vm-tools" >> "$pkgs"
fi

if [ "$ARCH" = "i686" ]; then
	FS_LABEL="ROSA_Plasma5_i686_${BUILD_ID}"
	sed -i "s/x86_64/i686/" "$repobase"
	sed -i "s/^lib64/lib/" "$pkgs"
fi

sed -i "s,repobase.ks,${repobase},g" "$conf"
sed -i "s,plasma5pack.ks,${pkgs},g" "$conf"

sleep "$SLEEP"

#dnf distrosync -y

dnf install -y		\
	coreutils	\
	findutils	\
	lsof		\
	sed		\
	tar		\
	util-linux	\
	/usr/bin/livecd-creator

if [ "$ARCH" = "aarch64" ]; then
	dnf install -y \
		dracut \
		wget
	mkdir -p /home/rpms
	pushd /home/rpms
#		wget http://abf-downloads.rosalinux.ru/lxqt_backports_personal/container/3666849/aarch64/main/release/livecd-tools-27.1-23-rosa2019.1.aarch64.rpm
#		wget http://abf-downloads.rosalinux.ru/lxqt_backports_personal/container/3666849/aarch64/main/release/python-imgcreate-sysdeps-27.1-23-rosa2019.1.aarch64.rpm
#		wget http://abf-downloads.rosalinux.ru/lxqt_backports_personal/container/3666849/aarch64/main/release/python3-imgcreate-27.1-23-rosa2019.1.aarch64.rpm

		wget http://abf-downloads.rosalinux.ru/survolog_personal/container/3665838/aarch64/main/release/livecd-tools-27.1-22.1-rosa2019.1.aarch64.rpm
		wget http://abf-downloads.rosalinux.ru/survolog_personal/container/3665838/aarch64/main/release/python-imgcreate-sysdeps-27.1-22.1-rosa2019.1.aarch64.rpm
		wget http://abf-downloads.rosalinux.ru/survolog_personal/container/3665838/aarch64/main/release/python3-imgcreate-27.1-22.1-rosa2019.1.aarch64.rpm

		dnf install -y *.rpm
	popd
fi

mkdir -p /home/results

livecd-creator --verbose	\
	--compression-type=xz	\
	--config="$conf"	\
	--fslabel="$FS_LABEL"

mv -v *.iso /home/results/
